@@ -19,9 +19,10 @@ from semantic_kernel.connectors.ai.open_ai import OpenAIChatPromptExecutionSetti
 if TYPE_CHECKING:
     from semantic_kernel.services.chat_completion_service import ChatCompletionService  # type: ignore[import-not-found]
 
-from .exceptions import LLMExecutionError
+from .exceptions import LLMExecutionError, SchemaValidationError
 from .formatters import detect_output_format, display_formatted_console, format_output_content
 from .io_operations import create_chat_history, load_schema_file
+from .retry import retry_network_operation, should_retry_llm_exception
 from .schema import generate_one_shot_example
 
 LOGGER = logging.getLogger(__name__)
@@ -103,8 +104,9 @@ class LLMExecutor:
         """
         return detect_output_format(Path(self.output_file) if self.output_file else None)
 
+    @retry_network_operation
     async def _execute_semantic_kernel_with_schema(self, chat_history: list) -> dict[str, Any]:
-        """Execute LLM task using Semantic Kernel with schema enforcement.
+        """Execute LLM task using Semantic Kernel with schema enforcement and retry.
 
         Args:
             chat_history: List of chat messages
@@ -164,8 +166,9 @@ class LLMExecutor:
 
         return _process_structured_response(content, self.schema_model, self.schema_dict, self.output_format)
 
+    @retry_network_operation
     async def _execute_sdk_with_schema(self, client_type: str, chat_history: list) -> dict[str, Any]:
-        """Execute LLM task using appropriate SDK with schema enforcement.
+        """Execute LLM task using appropriate SDK with schema enforcement and retry.
 
         Unified execution logic for both Azure and OpenAI SDKs.
 
@@ -265,7 +268,13 @@ class LLMExecutor:
                 LOGGER.info("✅ Azure SDK execution successful")
                 return result
             except Exception as e:
-                LOGGER.warning(f"⚠️ Azure SDK failed: {e}")
+                # Let retriable exceptions (SchemaValidationError, timeout errors, SDK errors) propagate to retry decorator
+                if should_retry_llm_exception(e):
+                    LOGGER.info(f"🔄 Azure SDK encountered retriable error, will retry: {e}")
+                    raise  # Propagate retriable exception to retry decorator
+
+                # Only convert truly non-retriable exceptions to LLMExecutionError
+                LOGGER.warning(f"⚠️ Azure SDK failed with non-retriable error: {e}")
                 raise LLMExecutionError(f"Schema enforcement failed with Azure SDK: {e}") from e
         else:
             # Try OpenAI SDK for OpenAI endpoints
@@ -275,7 +284,13 @@ class LLMExecutor:
                 LOGGER.info("✅ OpenAI SDK execution successful")
                 return result
             except Exception as e:
-                LOGGER.warning(f"⚠️ OpenAI SDK failed: {e}")
+                # Let retriable exceptions (SchemaValidationError, timeout errors, SDK errors) propagate to retry decorator
+                if should_retry_llm_exception(e):
+                    LOGGER.info(f"🔄 OpenAI SDK encountered retriable error, will retry: {e}")
+                    raise  # Propagate retriable exception to retry decorator
+
+                # Only convert truly non-retriable exceptions to LLMExecutionError
+                LOGGER.warning(f"⚠️ OpenAI SDK failed with non-retriable error: {e}")
                 raise LLMExecutionError(f"Schema enforcement failed with OpenAI SDK: {e}") from e
 
         # If we reach here, no endpoint was detected
@@ -401,56 +416,6 @@ async def _create_openai_client() -> AsyncOpenAI:
     )
 
 
-async def _execute_text_mode(
-    kernel: Kernel,
-    chat_history: list,
-    output_file: str | None = None,
-) -> dict[str, Any]:
-    """Execute LLM task using text mode (no schema enforcement).
-
-    Args:
-        kernel: Semantic Kernel instance
-        chat_history: List of chat messages
-        output_file: Optional output file path
-
-    Returns:
-        Dictionary containing execution results
-
-    Raises:
-        Exception: If text mode execution fails
-    """
-    # Get the chat completion service
-    service: ChatCompletionService | None = kernel.get_service("azure_openai")
-    if not service:
-        # Try alternative service IDs
-        service = kernel.get_service("openai")
-    if not service:
-        raise Exception("No chat completion service found")
-
-    # Create settings for text mode
-    settings = OpenAIChatPromptExecutionSettings(
-        service_id="azure_openai",
-    )
-
-    # Convert list to ChatHistory for Semantic Kernel compatibility
-    sk_chat_history = create_chat_history(chat_history)
-
-    # Execute without schema enforcement
-    result = await service.get_chat_message_contents(
-        chat_history=sk_chat_history,
-        settings=settings,
-    )
-
-    # Extract content from ChatMessageContent objects
-    if result and len(result) > 0:
-        content = result[0].content
-    else:
-        content = ""
-
-    output_format = detect_output_format(Path(output_file) if output_file else None)
-    return _process_text_response(content, output_format)
-
-
 def _process_structured_response(
     response: str,
     schema_model: type | None,
@@ -489,9 +454,10 @@ def _process_structured_response(
             }
 
         except json.JSONDecodeError as e:
-            LOGGER.warning(f"⚠️ Failed to parse structured response as JSON: {e}")
+            # Schema enforcement is active - parsing failure should trigger retry
+            LOGGER.error(f"❌ Schema enforced but JSON parsing failed: {e}")
             LOGGER.debug(f"   Raw response: {response[:200]}...")
-            return _process_text_response(response, output_format)
+            raise SchemaValidationError(f"Schema enforcement failed: Invalid JSON response - {e}") from e
 
     else:
         return _process_text_response(response, output_format)
